@@ -3,19 +3,24 @@ package ORDB::CPANTS;
 use 5.008005;
 use strict;
 use warnings;
-use ORLite::Mirror 1.12 ();
+use Params::Util   0.38 ();
+use ORLite         1.52 ();
+use ORLite::Mirror 1.22 ();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub import {
 	my $class = shift;
+	my $params = Params::Util::_HASH(shift) || {};
+
+	# Pass through any params from above
+	#$params->{url}    ||= 'http://cpants.perl.org/static/cpants_all.db.gz';
+	$params->{url}    ||= 'http://cpants.charsbar.org/static/cpants_all.db.gz';
+	$params->{maxage} ||= 7 * 24 * 60 * 60; # One week
 
 	# Prevent double-initialisation
 	$class->can('orlite') or
-	ORLite::Mirror->import( {
-		url    => 'http://cpants.perl.org/static/cpants_all.db.gz',
-		maxage => 7 * 24 * 60 * 60,
-	} );
+	ORLite::Mirror->import( $params );
 
 	return 1;
 }
@@ -177,7 +182,7 @@ Adam Kennedy
 
 =head1 COPYRIGHT
 
-Copyright 2009 Adam Kennedy.
+Copyright 2009 - 2012 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
